==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/DeviceAssuranceMacOSPlatformAllOfDiskEncryptionType.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.DiskEncryptionTypeDesktop;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * DeviceAssuranceMacOSPlatformAllOfDiskEncryptionType
 */
@JsonPropertyOrder({ DeviceAssuranceMacOSPlatformAllOfDiskEncryptionType.JSON_PROPERTY_INCLUDE })
@JsonTypeName("DeviceAssuranceMacOSPlatform_allOf_diskEncryptionType")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class DeviceAssuranceMacOSPlatformAllOfDiskEncryptionType implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_INCLUDE = "include";
    private List<DiskEncryptionTypeDesktop> include = null;

    public DeviceAssuranceMacOSPlatformAllOfDiskEncryptionType() {
    }

    public DeviceAssuranceMacOSPlatformAllOfDiskEncryptionType include(List<DiskEncryptionTypeDesktop> include) {

        this.include = include;
        return this;
    }

    public DeviceAssuranceMacOSPlatformAllOfDiskEncryptionType addincludeItem(DiskEncryptionTypeDesktop includeItem) {
        if (this.include == null) {
            this.include = new ArrayList<>();
        }
        this.include.add(includeItem);
        return this;
    }

    /**
     * Get include
     *
     * @return include
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_INCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<DiskEncryptionTypeDesktop> getInclude() {
        return include;
    }

    @JsonProperty(JSON_PROPERTY_INCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setInclude(List<DiskEncryptionTypeDesktop> include) {
        this.include = include;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DeviceAssuranceMacOSPlatformAllOfDiskEncryptionType deviceAssuranceMacOSPlatformAllOfDiskEncryptionType = (DeviceAssuranceMacOSPlatformAllOfDiskEncryptionType) o;
        return Objects.equals(this.include, deviceAssuranceMacOSPlatformAllOfDiskEncryptionType.include);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(include);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class DeviceAssuranceMacOSPlatformAllOfDiskEncryptionType {\n");
        sb.append("    include: ").append(toIndentedString(include)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/DeviceAssuranceMacOSPlatformAllOfDiskEncryptionType.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.DiskEncryptionTypeDesktop;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * DeviceAssuranceMacOSPlatformAllOfDiskEncryptionType
 */
@JsonPropertyOrder({ DeviceAssuranceMacOSPlatformAllOfDiskEncryptionType.JSON_PROPERTY_INCLUDE })
@JsonTypeName("DeviceAssuranceMacOSPlatform_allOf_diskEncryptionType")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class DeviceAssuranceMacOSPlatformAllOfDiskEncryptionType implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_INCLUDE = "include";
    private List<DiskEncryptionTypeDesktop> include = null;

    public DeviceAssuranceMacOSPlatformAllOfDiskEncryptionType() {
    }

    public DeviceAssuranceMacOSPlatformAllOfDiskEncryptionType include(List<DiskEncryptionTypeDesktop> include) {

        this.include = include;
        return this;
    }

    public DeviceAssuranceMacOSPlatformAllOfDiskEncryptionType addincludeItem(DiskEncryptionTypeDesktop includeItem) {
        if (this.include == null) {
            this.include = new ArrayList<>();
        }
        this.include.add(includeItem);
        return this;
    }

    /**
     * Get include
     *
     * @return include
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_INCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<DiskEncryptionTypeDesktop> getInclude() {
        return include;
    }

    @JsonProperty(JSON_PROPERTY_INCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setInclude(List<DiskEncryptionTypeDesktop> include) {
        this.include = include;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DeviceAssuranceMacOSPlatformAllOfDiskEncryptionType deviceAssuranceMacOSPlatformAllOfDiskEncryptionType = (DeviceAssuranceMacOSPlatformAllOfDiskEncryptionType) o;
        return Objects.equals(this.include, deviceAssuranceMacOSPlatformAllOfDiskEncryptionType.include);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(include);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class DeviceAssuranceMacOSPlatformAllOfDiskEncryptionType {\n");
        sb.append("    include: ").append(toIndentedString(include)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
